@@ -1,4 +1,4 @@
-//@line 38 "/usr/obj/i386/mozilla-thunderbird-2.0.0.12/mozilla/mail/extensions/newsblog/content/feed-subscriptions.js"
+//@line 38 "/usr/obj/i386/mozilla-thunderbird-2.0.0.16p0/mozilla/mail/extensions/newsblog/content/feed-subscriptions.js"
 
 const MSG_FOLDER_FLAG_TRASH = 0x0100;
 const IPS = Components.interfaces.nsIPromptService;
@@ -480,7 +480,7 @@ var gFeedSubscriptionsWindow = {
       return;
 
     var resource = rdf.GetResource(itemToRemove.url);
-    var feed = new Feed(resource);
+    var feed = new Feed(resource, this.mRSSServer);
     var ds = getSubscriptionsDS(this.mRSSServer);
 
     if (feed && ds)
